
Change Log
==========

1.0.3 (December 30, 2014)
'''''''''''''''''''''''''

 * Tweaked documentation. Reran tests on latest versions.
   Withdrew support for Python 2.5, which
   is no longer supported by my testing tools.

1.0
'''

  * Cleaned up source for better PEP8 conformance
  * Bumped version number to 1.0 as part of move to `semantic
    versioning <http://semver.org>`_, or at least enough of it so
    as to not screw up Python installation procedures (which don't
    seem to understand 0.401 is a lesser version that 0.5, because
    401 > 5).
